/* 
  	* AtomFeedAutoDiscovery.aspx.cs
	* Copyright  2002 - 2008 ToolButton Inc. All Rights Reserved.
*/
using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;
using Web20Tools.Feed.Atom;
using Web20Tools.Security; 
using Web20Tools.Feed.Crawler; 
using System.Reflection;
using System.Resources;   
#if(VS8)
using System.Collections.Generic;
using System.Collections.ObjectModel;
using Web20Tools.ExceptionFramework; 
#endif         

namespace Samples.Atom
{
	/// <summary>
	/// ATOM feed discovery.
	/// </summary>
	public class AtomFeedAutoDiscovery : System.Web.UI.Page
	{
        protected System.Web.UI.HtmlControls.HtmlForm Form1;
        protected System.Web.UI.WebControls.TextBox txtSiteURL;
        protected System.Web.UI.WebControls.Button btnDiscover;
        protected System.Web.UI.WebControls.Label lblMsg;
        protected System.Web.UI.WebControls.DataGrid dgFeeds;
        protected System.Web.UI.WebControls.HyperLink hlViewError;
        protected System.Web.UI.WebControls.Label lblError;

		private ResourceManager stringManager = new ResourceManager("Samples.SamplesResource",Assembly.GetExecutingAssembly()); 
	
		protected void Page_Load(object sender, System.EventArgs e)
		{
			// Put user code to initialize the page here
			
			if(!IsPostBack)
			{
				dgFeeds.Visible=true;
				txtSiteURL.Text = "http://news.google.com";
				if(dgFeeds.Visible)
					btnDiscover.Attributes.Add("OnClick","return checkForBlank();");

                hlViewError.Attributes.Add("OnClick", "return ShowError();");
			}
		}

		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.dgFeeds.ItemDataBound += new System.Web.UI.WebControls.DataGridItemEventHandler(this.dgFeeds_ItemDataBound);

		}
		#endregion

		protected void btnDiscover_Click(object sender, System.EventArgs e)
		{
#if(VS8)
            Collection<FeedInfo> fdinfoCollect = null;
#else
			FeedInfoCollection fdinfoCollect = null;
#endif
			DataTable dtTemp = new DataTable();
			dtTemp.Locale = System.Globalization.CultureInfo.InvariantCulture;    
			dgFeeds.DataSource = dtTemp;

			lblMsg.Text = stringManager.GetString("strBlank");
			try
			{
                License.LoadLicense();

                if (!txtSiteURL.Text.ToUpper().StartsWith("http://".ToUpper()))
                    txtSiteURL.Text = "http://" + txtSiteURL.Text;

				fdinfoCollect = AtomFeed.Discover(new Uri(txtSiteURL.Text));

                hlViewError.Text = stringManager.GetString("strBlank");
                hlViewError.NavigateUrl = stringManager.GetString("strBlank");
                lblError.Text = stringManager.GetString("strBlank");

				if (fdinfoCollect == null)
				{
					lblMsg.Text = stringManager.GetString("strUnable");
					dgFeeds.Visible = false;

                    hlViewError.Text = stringManager.GetString("strViewError");
                    hlViewError.NavigateUrl = "#";
                    lblError.Text = stringManager.GetString("strUnable");                    
				}
			}
			catch (InvalidLicenseException ilex) 
			{
				lblMsg.Text = stringManager.GetString("strLicenseException");
				dgFeeds.Visible = false;

                hlViewError.Text = stringManager.GetString("strViewError");
                hlViewError.NavigateUrl = "#";
                lblError.Text = ilex.Message;
			}
            catch (InvalidLicenseInfoException iliex)
            {
                lblMsg.Text = stringManager.GetString("strInvalidLicenseInfo");
                dgFeeds.Visible = false;

                hlViewError.Text = stringManager.GetString("strViewError");
                hlViewError.NavigateUrl = "#";
                lblError.Text = iliex.Message;
            }	
			catch(Exception ex)
			{	
				dgFeeds.Visible = false;
				lblMsg.Text = string.Format(stringManager.GetString("strNoFeedDiscover"),"ATOM" );

                hlViewError.Text = stringManager.GetString("strViewError");
                hlViewError.NavigateUrl = "#";
                lblError.Text = ex.Message;
			}

			if (fdinfoCollect != null)
			{
				if (fdinfoCollect.Count > 0)
				{
					DataTable dt = new DataTable();    
					dt.Locale = System.Globalization.CultureInfo.InvariantCulture;    
					dt.Columns.Add("FeedUrl");
					dt.Columns.Add("FeedType");
					dt.Columns.Add("FeedTitle");
					dt.Columns.Add("FeedContent");
					DataRow dr;
					foreach (FeedInfo Fdinfo in fdinfoCollect)
					{
						dr = dt.NewRow();
						dr["FeedUrl"] = Fdinfo.FeedUrl;
						dr["FeedType"] =  Fdinfo.FeedType.ToString().ToUpper();
						dr["FeedTitle"] = Fdinfo.FeedTitle;
						dr["FeedContent"] = Fdinfo.FeedContentType;
						dt.Rows.Add(dr);
					}
					dgFeeds.Visible = true;
					dgFeeds.DataSource = dt;
					dgFeeds.DataBind();					
				}
				else
				{
					dgFeeds.Visible=false;
					lblMsg.Text = string.Format(stringManager.GetString("strNoFeedDiscover"),"ATOM" ) ;
				}
			}
		}

		private void dgFeeds_ItemDataBound(object sender, DataGridItemEventArgs e)
		{
			if(e.Item.ItemType == ListItemType.Item || e.Item.ItemType == ListItemType.AlternatingItem)
			{
				e.Item.Cells[0].Text = e.Item.Cells[0].Text.Replace("/","/ ");
				e.Item.Cells[0].Text = e.Item.Cells[0].Text.Replace("/ / ","//");
				e.Item.Cells[0].Width = Unit.Percentage(50);
				e.Item.Cells[0].BackColor = System.Drawing.Color.Cornsilk;
				
				e.Item.Cells[1].Width = Unit.Percentage(5);
				e.Item.Cells[1].ForeColor = System.Drawing.Color.Red;

				e.Item.Cells[2].Width = Unit.Percentage(20);
				e.Item.Cells[2].ForeColor = System.Drawing.Color.Blue;

				e.Item.Cells[3].Text = e.Item.Cells[3].Text.Replace("/","/ ");
				e.Item.Cells[3].Width = Unit.Percentage(10);
				e.Item.Cells[3].ForeColor = System.Drawing.Color.Red;
			}
		}
	}
}
