' AtomFeedAutoDiscovery.aspx.vb
' Copyright  2002 - 2008 ToolButton Inc. All Rights Reserved.

Imports System
Imports System.Collections 
Imports System.ComponentModel 
Imports System.Data 
Imports System.Drawing 
Imports System.Web 
Imports System.Web.SessionState 
Imports System.Web.UI 
Imports System.Web.UI.WebControls 
Imports System.Web.UI.HtmlControls 
Imports Web20Tools.Feed.Atom 
Imports Web20Tools.Feed.Crawler
Imports System.Resources
Imports System.Reflection
Imports Web20Tools.Security
Imports Web20Tools.ExceptionFramework
#If VS8 Then
Imports System.Collections.Generic
Imports System.Collections.ObjectModel
#End If
Namespace Samples.Atom
    ''' <summary>
    ''' An ATOM feed discovery
    ''' </summary>
    Public Class AtomFeedAutoDiscovery
        Inherits System.Web.UI.Page
        Protected WithEvents Form1 As System.Web.UI.HtmlControls.HtmlForm
        Protected WithEvents txtSiteURL As System.Web.UI.WebControls.TextBox
        Protected WithEvents btnDiscover As System.Web.UI.WebControls.Button
        Protected WithEvents lblMsg As System.Web.UI.WebControls.Label
        Protected WithEvents dgFeeds As System.Web.UI.WebControls.DataGrid
        Protected hlViewError As System.Web.UI.WebControls.HyperLink
        Protected lblError As System.Web.UI.WebControls.Label

        Private stringManager As New ResourceManager("Samples.SamplesResource", [Assembly].GetExecutingAssembly())
        Private Sub Page_Load(ByVal sender As Object, ByVal e As System.EventArgs)

            If Not IsPostBack Then
                dgFeeds.Visible = True
                txtSiteURL.Text = "http://news.google.com"
                If dgFeeds.Visible Then
                    btnDiscover.Attributes.Add("OnClick", "return checkForBlank();")
                End If
                hlViewError.Attributes.Add("OnClick", "return ShowError();")
            End If
        End Sub
        Protected Overloads Overrides Sub OnInit(ByVal e As EventArgs)
            InitializeComponent()
            MyBase.OnInit(e)
        End Sub

        Private Sub InitializeComponent()
            AddHandler Me.btnDiscover.Click, AddressOf Me.btnDiscover_Click
            AddHandler Me.dgFeeds.ItemDataBound, AddressOf Me.dgFeeds_ItemDataBound
            AddHandler Me.Load, AddressOf Me.Page_Load
        End Sub

        Private Sub btnDiscover_Click(ByVal sender As Object, ByVal e As System.EventArgs)
#If VS8 Then
            Dim fdinfoCollect As Collection(Of FeedInfo) = Nothing
#Else
            Dim fdinfoCollect As FeedInfoCollection = Nothing
#End If
            Dim dtTemp As DataTable = New DataTable
            dtTemp.Locale = System.Globalization.CultureInfo.InvariantCulture
            dgFeeds.DataSource = dtTemp
            lblMsg.Text = String.Empty
            Try
                License.LoadLicense()
                If Not txtSiteURL.Text.ToUpper().StartsWith("http://".ToUpper()) Then
                    txtSiteURL.Text = "http://" + txtSiteURL.Text
                End If
                fdinfoCollect = AtomFeed.Discover(New Uri(txtSiteURL.Text))

                hlViewError.Text = stringManager.GetString("strBlank")
                hlViewError.NavigateUrl = stringManager.GetString("strBlank")
                lblError.Text = stringManager.GetString("strBlank")

                If fdinfoCollect Is Nothing Then
                    lblMsg.Text = stringManager.GetString("strUnable")
                    dgFeeds.Visible = False

                    hlViewError.Text = stringManager.GetString("strViewError")
                    hlViewError.NavigateUrl = "#"
                    lblError.Text = stringManager.GetString("strUnable")
                End If
            Catch ex As InvalidLicenseException
                dgFeeds.Visible = False
                lblMsg.Text = stringManager.GetString("strLicenseException")

                hlViewError.Text = stringManager.GetString("strViewError")
                hlViewError.NavigateUrl = "#"
                lblError.Text = ex.Message
            Catch liex As InvalidLicenseInfoException
                dgFeeds.Visible = False
                lblMsg.Text = stringManager.GetString("strInvalidLicenseInfo")

                hlViewError.Text = stringManager.GetString("strViewError")
                hlViewError.NavigateUrl = "#"
                lblError.Text = liex.Message
            Catch ex As Exception
                dgFeeds.Visible = False
                lblMsg.Text = String.Format(stringManager.GetString("strNoFeedDiscover"), "ATOM")

                hlViewError.Text = stringManager.GetString("strViewError")
                hlViewError.NavigateUrl = "#"
                lblError.Text = ex.Message
            End Try
            If Not (fdinfoCollect Is Nothing) Then
                If fdinfoCollect.Count > 0 Then
                    Dim dt As DataTable = New DataTable
                    dt.Locale = System.Globalization.CultureInfo.InvariantCulture
                    dt.Columns.Add("FeedUrl")
                    dt.Columns.Add("FeedType")
                    dt.Columns.Add("FeedTitle")
                    dt.Columns.Add("FeedContent")
                    Dim dr As DataRow
                    For Each Fdinfo As FeedInfo In fdinfoCollect
                        dr = dt.NewRow
                        dr("FeedUrl") = Fdinfo.FeedUrl
                        dr("FeedType") = Fdinfo.FeedType.ToString.ToUpper
                        dr("FeedTitle") = Fdinfo.FeedTitle
                        dr("FeedContent") = Fdinfo.FeedContentType
                        dt.Rows.Add(dr)
                    Next
                    dgFeeds.Visible = True
                    dgFeeds.DataSource = dt
                    dgFeeds.DataBind()
                Else
                    dgFeeds.Visible = False
                    lblMsg.Text = String.Format(stringManager.GetString("strNoFeedDiscover"), "ATOM")
                End If
            End If
        End Sub

        Private Sub dgFeeds_ItemDataBound(ByVal sender As Object, ByVal e As DataGridItemEventArgs)
            If e.Item.ItemType = ListItemType.Item OrElse e.Item.ItemType = ListItemType.AlternatingItem Then
                e.Item.Cells(0).Text = e.Item.Cells(0).Text.Replace("/", "/ ")
                e.Item.Cells(0).Text = e.Item.Cells(0).Text.Replace("/ / ", "//")
                e.Item.Cells(0).Width = Unit.Percentage(50)
                e.Item.Cells(0).BackColor = System.Drawing.Color.Cornsilk
                e.Item.Cells(1).Width = Unit.Percentage(5)
                e.Item.Cells(1).ForeColor = System.Drawing.Color.Red
                e.Item.Cells(2).Width = Unit.Percentage(20)
                e.Item.Cells(2).ForeColor = System.Drawing.Color.Blue
                e.Item.Cells(3).Text = e.Item.Cells(3).Text.Replace("/", "/ ")
                e.Item.Cells(3).Width = Unit.Percentage(10)
                e.Item.Cells(3).ForeColor = System.Drawing.Color.Red
            End If
        End Sub
    End Class
End Namespace
