/*
	* ConvertAtom.cs
	* Copyright  2002 - 2008 ToolButton Inc. All Rights Reserved. 
*/

using System;
using System.Windows.Forms;
using Web20Tools.Feed.Atom;
using System.Reflection;
using System.Resources;
using Web20Tools.Security;
using Web20Tools.ExceptionFramework;

namespace AtomConvert
{
    public partial class ConvertAtom : Form
    {
        AtomFeed10 feed10;
        AtomFeed03 feed03;
        AtomFeed feed;

        ResourceManager stringManager = new ResourceManager("AtomConvert.AtomConvertResource", Assembly.GetExecutingAssembly());
        public ConvertAtom()
        {
            InitializeComponent();
        }

        private void btnBrowse_Click(object sender, EventArgs e)
        {
            OpenFileDialog fupAtom = new OpenFileDialog();

            if (LoadAtom_flg == false)
            {
                this.fupAtom.Reset();
                this.fupAtom.InitialDirectory = Environment.CurrentDirectory.Substring(0, (Environment.CurrentDirectory.ToString().IndexOf("bin", 0) - 1)); //Application.StartupPath;  //Path.GetFullPath("AtomLoad");  //
                LoadAtom_flg = true;
            }
            else
            {
                this.fupAtom.RestoreDirectory = true;
            }
            
            this.fupAtom.Filter = "(*.xml)|*.xml";
        

            if (this.fupAtom.ShowDialog() == DialogResult.OK)
            {
                txtData.Text = string.Empty;
                txtFile.Text = this.fupAtom.FileName;
            }            
        }

        private void btnSave_Click(object sender, EventArgs e)
        {
            try
            {
                SaveFileDialog saveAtomFile = new SaveFileDialog();
              
                this.saveAtomFile.Filter = "(*.xml)|*.xml";
                this.saveAtomFile.RestoreDirectory = true;

                if (this.saveAtomFile.ShowDialog() == DialogResult.OK)
                {  
                    switch (feed.Version)
                    {
                        case AtomVersion.Atom03:                          
                            feed10.Save(this.saveAtomFile.FileName.ToString());                           
                            break;
                        case AtomVersion.Atom10:                          
                            feed03.Save(this.saveAtomFile.FileName.ToString());
                            break;
                    }                                        
                     txturl.Text = string.Empty;
                     txtFile.Text = string.Empty;
                     btnSave.Enabled = false;
                }             
            }
            catch (Exception)
            {
                btnSave.Enabled = false;
                MessageBox.Show(stringManager.GetString("strXml"), stringManager.GetString("strCaption"));
                return;
            }
        }

        private void btnConvert_Click(object sender, EventArgs e)
        {
            Atom03 objatom03 = new Atom03();
            Atom10 objatom10 = new Atom10();

            try
            {
                AtomLicenseContext.LoadLicenseInfo("License Key", "License Owner");  
                if (rbtnatom03.Checked == true)
                {
                    if (ValidateFile())
                    {
                        feed = AtomFeed.Load(fupAtom.FileName);
                    
                    }
                    else if (ValidateUrl())
                    {
                        feed = AtomFeed.Load(txturl.Text.ToString());                 
                    }
                    else
                    {
                        MessageBox.Show(stringManager.GetString("strSelect"), stringManager.GetString("strCaption"));
                        return;
                    }
                   
                    if (feed.Version == AtomVersion.Atom10)
                    {
                        feed10 = (AtomFeed10)feed;
                        feed03 = feed10.Convert(AtomVersion.Atom03);
                        txtData.Text = objatom03.DisplayFeed03(feed03);
                    }
                    else
                    {
                        MessageBox.Show(stringManager.GetString("strAtom03"), stringManager.GetString("strCaption"));
                        return;
                    }
                 }
                 else if (rbtnatom1.Checked == true)
                 {
                     if (ValidateFile())
                     {
                         feed = AtomFeed.Load(fupAtom.FileName);                     
                     }
                     else if(ValidateUrl())
                     {
                         feed = AtomFeed.Load(txturl.Text.ToString());
                     }
                     else
                     {
                         MessageBox.Show(stringManager.GetString("strSelect"), stringManager.GetString("strCaption"));
                        return;                      
                     }
                    
                     if (feed.Version == AtomVersion.Atom03)
                     {
                        feed03 = (AtomFeed03)feed;
                        feed10 = feed03.Convert(AtomVersion.Atom10);
                        txtData.Text = objatom10.DisplayFeed10(feed10);
                     }
                     else
                     {
                        MessageBox.Show(stringManager.GetString("strAtom10"), stringManager.GetString("strCaption"));
                        return;                    
                     }
                }
               btnSave.Enabled = true;             
            }
            catch (AtomReaderException ex)
            {
                if (ex.InnerException != null && ex.InnerException is InvalidLicenseException)
                {
                    LicenseMsgForm msgForm = new LicenseMsgForm();
                    msgForm.ShowDialog();
                    msgForm.Dispose();
                }
                else
                    MessageBox.Show(ex.Message, stringManager.GetString("strCaption"));
            }
            catch (InvalidLicenseInfoException)
            {
                MessageBox.Show(stringManager.GetString("strInvalidLicenseInfo"), stringManager.GetString("strCaption"));
            }
            catch (InvalidLicenseException)
            {
                LicenseMsgForm msgForm = new LicenseMsgForm();
                msgForm.ShowDialog();
                msgForm.Dispose();
            }
            catch (Exception)
            {
                MessageBox.Show(stringManager.GetString("strConvertError"), stringManager.GetString("strCaption")); ;
                btnSave.Enabled = false;               
            }
        }

        private void ConvertAtom_Load(object sender, EventArgs e)
        {
            txturl.Text = string.Empty;
            txtFile.Text = string.Empty;         
        }

        private void rbturl_CheckedChanged(object sender, EventArgs e)
        {
            txtFile.Text = string.Empty;
        }

        private void rbtfile_CheckedChanged(object sender, EventArgs e)
        {
            txturl.Text = string.Empty;
        }

        public bool ValidateFile()
        {            
            if (rbtfile.Checked == true && txtFile.Text.Length != 0)
            {
                if (!System.IO.File.Exists(txtFile.Text))
                {
                    MessageBox.Show(stringManager.GetString("strInvalidFile"), stringManager.GetString("strCaption"));
                    return false;             
                }
                return true;
            }
            else
            {
                return false;            
            }           
        }

        public bool ValidateUrl()
        {
            if (rbturl.Checked == true && txturl.Text.Length != 0)
            {
                if (!Atom03.CheckUrl(txturl.Text.ToString()))
                {
                    MessageBox.Show(stringManager.GetString("strInvalidUrl"), stringManager.GetString("strCaption"));
                    return false;
                }
                else
                {
                    return true;                
                }
            }
            else
            {
                return false; 
            }
        }
    }
}