/*
	* LoadAtom.cs
	* Copyright  2002 - 2008 ToolButton Inc. All Rights Reserved. 
*/

using System;
using System.Windows.Forms;
using Web20Tools.Feed.Atom;
using System.Reflection;
using System.Resources;
using Web20Tools.Security;
using Web20Tools.ExceptionFramework;

namespace AtomLoad
{
    public partial class LoadAtom : Form
    {
        AtomFeed feed;
        ResourceManager stringManager = new ResourceManager("AtomLoad.AtomLoadResource", Assembly.GetExecutingAssembly());
        public LoadAtom()
        {            
            InitializeComponent();
        }         

        private void btnBrowse_Click(object sender, EventArgs e)
        { 
            OpenFileDialog fupAtom = new OpenFileDialog();
            if (LoadAtom_flg == false)
            {
                this.fupAtom.Reset();
                this.fupAtom.InitialDirectory = Environment.CurrentDirectory.Substring(0, (Environment.CurrentDirectory.ToString().IndexOf("bin", 0) - 1)); //Application.StartupPath;  //Path.GetFullPath("AtomLoad");  //
                LoadAtom_flg = true;
            }
            else
            {
                this.fupAtom.RestoreDirectory = true;
            }
            this.fupAtom.Filter = "(*.xml)|*.xml";
           
            if (this.fupAtom.ShowDialog() == DialogResult.OK)
            {
                txtData.Text = string.Empty;
                txtFile.Text = this.fupAtom.FileName;
            }           
        }
      
        private void btnSave_Click(object sender, EventArgs e)
        {
            if (txtData.Text != string.Empty)
            {
                txtData.Text = string.Empty;
                try
                {
                    SaveFileDialog saveAtomFile = new SaveFileDialog();

                    this.saveAtomFile.Filter = "(*.xml)|*.xml";

                    if (this.saveAtomFile.ShowDialog() == DialogResult.OK)
                    {
                        if (rbtfile.Checked == true)
                        {
                            if (ValidateFile())
                            {
                                feed = AtomFeed.Load(txtFile.Text.ToString());
                            }
                            else
                            {
                                MessageBox.Show(stringManager.GetString("strFile"), stringManager.GetString("strCaption"));
                                return;
                            }
                        }
                        else if (rbturl.Checked == true)
                        {
                            if (ValidateUrl())
                            {
                                feed = AtomFeed.Load(txturl.Text.ToString());
                            }
                            else
                            {
                                MessageBox.Show(stringManager.GetString("strUrl"), stringManager.GetString("strCaption"));
                                return;
                            }
                        }
                        else
                        {
                            MessageBox.Show(stringManager.GetString("strSelect"), stringManager.GetString("strCaption"));
                            return;
                        }

                        switch (feed.Version)
                        {
                            case AtomVersion.Atom03:
                                AtomFeed03 feed03 = (AtomFeed03)feed;
                                feed03.Save(this.saveAtomFile.FileName.ToString());
                                break;
                            case AtomVersion.Atom10:
                                AtomFeed10 feed10 = (AtomFeed10)feed;
                                feed10.Save(this.saveAtomFile.FileName.ToString());
                                break;
                        }

                        txturl.Text = string.Empty;
                        txtFile.Text = string.Empty;
                    }
                    LoadAtom_flg = true;

                }
                catch (Exception)
                {
                    MessageBox.Show(stringManager.GetString("strSaveError"), stringManager.GetString("strCaption"));
                    return;
                }
            }
        }

        private void btnLoad_Click(object sender, EventArgs e)
        {
            txtData.Text = string.Empty;
            Atom03 objatom03 = new Atom03();
            Atom10 objatom10 = new Atom10();

            try
            {
                AtomLicenseContext.LoadLicenseInfo("License Key", "License Owner");  
                if (rbtfile.Checked == true)
                {
                    if (ValidateFile())
                    {
                        feed = AtomFeed.Load(fupAtom.FileName);
                    }

                }
                else if (rbturl.Checked == true)
                {
                    if (ValidateUrl())
                    {
                        feed = AtomFeed.Load(txturl.Text.ToString());
                    }
                   
                }
                else
                {
                    MessageBox.Show(stringManager.GetString("strSelect"), stringManager.GetString("strCaption"));
                    return;
                }
                switch (feed.Version)
                {
                    case AtomVersion.Atom03:
                        txtData.Text = objatom03.DisplayFeed03((AtomFeed03)feed);
                        break;
                    case AtomVersion.Atom10:
                        txtData.Text = objatom10.DisplayFeed10((AtomFeed10)feed);
                        break;
                }
            }
            catch (AtomReaderException ex)
            {
                if (ex.InnerException != null && ex.InnerException is InvalidLicenseException)
                {
                    LicenseMsgForm msgForm = new LicenseMsgForm();
                    msgForm.ShowDialog();
                    msgForm.Dispose();
                }
                else
                    MessageBox.Show(ex.Message, stringManager.GetString("strCaption"));
            }
            catch (InvalidLicenseInfoException)
            {
                MessageBox.Show(stringManager.GetString("strInvalidLicenseInfo"), stringManager.GetString("strCaption"));
            }
            catch (InvalidLicenseException)
            {
                LicenseMsgForm msgForm = new LicenseMsgForm();
                msgForm.ShowDialog();
                msgForm.Dispose();
            }
            catch(Exception)
            {
                MessageBox.Show(stringManager.GetString("strFeedError"), stringManager.GetString("strCaption"));
            }           
        }

        public bool ValidateFile()
        {
            if (rbtfile.Checked == true && txtFile.Text.Length != 0)
            {
                if (!System.IO.File.Exists(txtFile.Text))
                {
                    MessageBox.Show(stringManager.GetString("strInvalidFile"), stringManager.GetString("strCaption"));
                    return false;
                }
                return true;
            }
            else
            {
                return false;
            }
        }

        public bool ValidateUrl()
        {
            if (rbturl.Checked == true && txturl.Text != "")
            {
                if (!Atom03.CheckUrl(txturl.Text.ToString()))
                {
                    MessageBox.Show(stringManager.GetString("strInvalidUrl"), stringManager.GetString("strCaption"));
                    return false;
                }
                else
                {
                    return true;
                }
            }
            else
            {
                return false;
            }

        }
     
        private void rbtfile_CheckedChanged(object sender, EventArgs e)
        {
            txturl.Text = string.Empty;           
        }

        private void rbturl_CheckedChanged(object sender, EventArgs e)
        {
            txtFile.Text = string.Empty;         
        }


    }
}